summaryrefslogtreecommitdiffstats
path: root/source/PluginManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'source/PluginManager.h')
-rw-r--r--source/PluginManager.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/source/PluginManager.h b/source/PluginManager.h
index 655081568..9268fe66d 100644
--- a/source/PluginManager.h
+++ b/source/PluginManager.h
@@ -29,6 +29,9 @@ class cPickup;
struct TakeDamageInfo;
class cPawn;
+// fwd: CommandOutput.h
+class cCommandOutputCallback;
+
@@ -191,8 +194,8 @@ public: // tolua_export
/// Returns true if the console command is in the command map
bool IsConsoleCommandBound(const AString & a_Command); // tolua_export
- /// Executes the command split into a_Split, as if it was given on the console. Returns true if executed.
- bool ExecuteConsoleCommand(const AStringVector & a_Split); // tolua_export
+ /// Executes the command split into a_Split, as if it was given on the console. Returns true if executed. Output is sent to the a_Output callback
+ bool ExecuteConsoleCommand(const AStringVector & a_Split, cCommandOutputCallback & a_Output);
private:
friend class cRoot;